#!/bin/bash

# User-defined variables
GITEA_USER=""
GITEA_TOKEN=""
GITEA_URL="git.sthope.dev"
PACKAGE_TYPE="composer"  # Possible values: "composer", "npm", etc.
UPLOAD_FILE="/path/to/project.zip"
COMPOSER_VERSION="latest"

# Ensure file exists before uploading
if [[ ! -f "$UPLOAD_FILE" ]]; then
  echo "Error: File '$UPLOAD_FILE' does not exist."
  exit 1
fi

# Check for protocol in GITEA_URL and add it if missing
if [[ ! "$GITEA_URL" =~ ^https?:// ]]; then
  GITEA_URL="https://$GITEA_URL"
fi

# Determine API URL based on PACKAGE_TYPE
if [[ "$PACKAGE_TYPE" == "composer" ]]; then
  URL="$GITEA_URL/api/packages/$GITEA_USER/composer?version=$COMPOSER_VERSION"
elif [[ "$PACKAGE_TYPE" == "npm" ]]; then
  URL="$GITEA_URL/api/packages/$GITEA_USER/npm?version=$COMPOSER_VERSION"
else
  echo "Error: Unsupported package type '$PACKAGE_TYPE'."
  exit 1
fi

# Check if curl is installed, install if not
if ! command -v curl &> /dev/null; then
  echo "curl could not be found, installing..."
  apt update && apt install -y curl
fi

# Upload file to Gitea
GITEA_UPLOAD=$(curl --user "$GITEA_USER:$GITEA_TOKEN" --upload-file "$UPLOAD_FILE" "$URL")

# Check if curl command was successful
if [[ $? -ne 0 ]]; then
  echo "Error: Upload failed."
  exit 1
fi

# Check Gitea's response (HTTP status code)
HTTP_STATUS=$(echo "$GITEA_UPLOAD" | jq -r '.status')  # Assuming response JSON contains a 'status' field
if [[ "$HTTP_STATUS" != "success" ]]; then
  echo "Error: Upload failed with response: $GITEA_UPLOAD"
  exit 1
fi

# Print upload response
echo "Upload successful: $GITEA_UPLOAD"
